[−][src]Module postgres_array::array
Structs
| Array | A multi-dimensional array. |
| IntoIter | An iterator over values of an |
| Iter | An iterator over references to values of an |
| IterMut | An iterator over mutable references to values of an |
Traits
| ArrayIndex | A trait implemented by types that can index into an |